@@ -6,7 +6,7 @@ class SubTopicCache(object):
         self.topicMap = dict()
 
     def exists(self, topic):
-        return self.topicMap.has_key(topic)
+        return topic in self.topicMap
 
     def put(self, topic):
         self.topicMap[topic] = ''
